Module orphan

Module orphan 

Orphan namespace of the module.

Macros

inspect_to_str_type_of
Macro to inspect type of a variable and its size exporting it as a string.
inspect_type_of
Macro to inspect type of a variable and its size printing into stdout and exporting it as a string.